@@ -23,11 +23,11 @@ while [[ "$#" -gt 0 ]]; do
   esac
   shift 1
 done
-UPSTREAM_JOB_NAME="crw-operator-installer-and-ls-deps_${JOB_BRANCH}"
+UPSTREAM_JOB_NAME="crw-deprecated_${JOB_BRANCH}"
 jenkinsURL="https://codeready-workspaces-jenkins.rhev-ci-vms.eng.rdu2.redhat.com/job/${UPSTREAM_JOB_NAME}"
 theTarGzs="
-lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/stacks/dependencies/php/target/codeready-workspaces-stacks-language-servers-dependencies-php.tar.gz
-lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/stacks/dependencies/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-xdebug.tar.gz
+lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-x86_64.tar.gz
+lastSuccessfulBuild/artifact/codeready-workspaces-deprecated/php/target/codeready-workspaces-stacks-language-servers-dependencies-php-xdebug-x86_64.tar.gz
 "
 lastSuccessfulURL="${jenkinsURL}/lastSuccessfulBuild/api/xml?xpath=//" # id or description
 
@@ -67,7 +67,7 @@ function parseCommitLog ()
 	# che-ls-jdt @ 288b75765175d368480a688c8f3a77ce4758c72d (0.0.3) ::
 	# che @ f34f4c6c82de35081351e0b0686b1ae6589735d4 (6.19.0-SNAPSHOT) ::
 	# codeready-workspaces @ 184e24bee5bd923b733fa8c9f4b055a9caad40d2 (1.1.0.GA) ::
-	# codeready-workspaces-deprecated @ 620a53c5b0a1bbc02ba68e96be94ec3b932c9bee (1.0.0.GA-SNAPSHOT) ::
+	# codeready-workspaces-deprecated @ 620a53c5b0a1bbc02ba68e96be94ec3b932c9bee ::
 	# codeready-workspaces-assembly-main.tar.gz
 	# codeready-workspaces-stacks-language-servers-dependencies-bayesian.tar.gz
 	# codeready-workspaces-stacks-language-servers-dependencies-node.tar.gz
@@ -78,12 +78,14 @@ function parseCommitLog ()
 	GHR="https://github.com/redhat-developer/"
 	while [[ "$#" -gt 0 ]]; do
 	  case $1 in
-		'crw_master'|'crw_stable-branch'|'crw-operator-installer-and-ls-deps_'*) JOB_NAME="$1"; shift 2;;
+		'crw_master'|'crw_stable-branch'|'crw-deprecated_'*) JOB_NAME="$1"; shift 2;;
 		'Build'*) BUILD_NUMBER="$2"; BUILD_NUMBER=${BUILD_NUMBER#\#}; shift 6;; # trim # from the number, ignore timestamp
 		'che-dev'|'che-parent'|'che-lib'|'che-ls-jdt'|'che') 
 			sha="$3"; addLabeln "git.commit.eclipse__${1}" "${GHE}${1}/commit/${sha:0:7}"; addLabel "pom.version.eclipse__${1}" "${4:1:-1}" " "; shift 5;;
-		'codeready-workspaces'|'codeready-workspaces-deprecated') 
+		'codeready-workspaces')
 			sha="$3"; addLabeln "git.commit.redhat-developer__${1}" "${GHR}${1}/commit/${sha:0:7}"; addLabel "pom.version.redhat-developer__${1}" "${4:1:-1}" " "; shift 5;;
+		'codeready-workspaces-deprecated')
+			sha="$3"; addLabeln "git.commit.redhat-developer__${1}" "${GHR}${1}/commit/${sha:0:7}"; shift 4;;
 		*'tar.gz') tarballs="${tarballs} $1"; shift 1;;
 		*) OTHER="${OTHER} $1"; shift 1;; 
 	  esac
@@ -129,6 +131,12 @@ function getFingerprints ()
 # get the public URL for the tarball(s)
 outputFiles=""
 
+
+#### fetch MANUALLY ADDED ARTIFACTS FROM kcrane - these are build by hand and therefore are not allowed in a GA
+log "[WARN] p and z sources not updated.  Manually built until have VM"
+rhpkg sources
+
+#### override any existing tarballs with newer ones from Jenkins build
 for theTarGz in ${theTarGzs}; do
 	outputFile=${theTarGz##*/}
 	log "[INFO] Download ${jenkinsURL}/${theTarGz}:"
@@ -140,6 +148,10 @@ for theTarGz in ${theTarGzs}; do
 	fi
 done
 
+#### ensure that MANUALLY ADDED ARTIFACTS FROM kcrane persist into sources file
+outputFiles="${outputFiles} codeready-workspaces-stacks-language-servers-dependencies-php-s390x.tar.gz"
+outputFiles="${outputFiles} codeready-workspaces-stacks-language-servers-dependencies-php-xdebug-s390x.tar.gz"
+
 if [[ ${outputFiles} ]]; then
 	log "[INFO] Upload new sources:${outputFiles}"
 	rhpkg new-sources ${outputFiles}
