@@ -116,6 +116,39 @@ function strcasecmp ($str1, $str2) {}
  */
 function strncasecmp ($str1, $str2, $len) {}
 
+/**
+ * The function returns {@see true} if the passed $haystack starts from the
+ * $needle string or {@see false} otherwise.
+ *
+ * @param string $haystack
+ * @param string $needle
+ * @return bool
+ * @since 8.0
+ */
+function str_starts_with(string $haystack, string $needle) : bool {}
+
+/**
+ * The function returns {@see true} if the passed $haystack ends with the
+ * $needle string or {@see false} otherwise.
+ *
+ * @param string $haystack
+ * @param string $needle
+ * @return bool
+ * @since 8.0
+ */
+function str_ends_with(string $haystack, string $needle) : bool {}
+
+/**
+ * Checks if $needle is found in $haystack and returns a boolean value
+ * (true/false) whether or not the $needle was found.
+ *
+ * @param string $haystack
+ * @param string $needle
+ * @return bool
+ * @since 8.0
+ */
+function str_contains(string $haystack, string $needle) : bool {}
+
 /**
  * Return the current key and value pair from an array and advance the array cursor
  * @link https://php.net/manual/en/function.each.php
@@ -135,6 +168,7 @@ function strncasecmp ($str1, $str2, $len) {}
  * array contents, <b>each</b> returns
  * false.
  * @deprecated 7.2 Use a foreach loop instead.
+ * @removed 8.0
  */
 function each (array &$array) {}
 
@@ -431,7 +465,7 @@ function function_exists ($function_name) {}
  * @param bool $autoload [optional] Whether to autoload if the original class is not found.
  * @return bool true on success or false on failure.
  */
-function class_alias ($original, $alias, $autoload = TRUE) {}
+function class_alias ($original, $alias, $autoload = true) {}
 
 /**
  * Returns an array with the names of included or required files
@@ -473,7 +507,7 @@ function get_required_files () {}
  * belongs to a class which is a subclass of
  * <i>class_name</i>, false otherwise.
  */
-function is_subclass_of ($object, $class_name, $allow_string = TRUE) {}
+function is_subclass_of ($object, $class_name, $allow_string = true) {}
 
 /**
  * Checks if the object is of this class or has this class as one of its parents
@@ -491,7 +525,7 @@ function is_subclass_of ($object, $class_name, $allow_string = TRUE) {}
  * @return bool <b>TRUE</b> if the object is of this class or has this class as one of
  * its parents, <b>FALSE</b> otherwise.
  */
-function is_a ($object, $class_name, $allow_string = FALSE) {}
+function is_a ($object, $class_name, $allow_string = false) {}
 
 /**
  * Get the default properties of the class
@@ -662,7 +696,7 @@ function get_declared_traits() {}
  * the user defined ones using $arr["user"] (see example
  * below).
  */
-function get_defined_functions ($exclude_disabled = FALSE) {}
+function get_defined_functions ($exclude_disabled = false) {}
 
 /**
  * Returns an array of all defined variables
@@ -682,6 +716,7 @@ function get_defined_vars () {}
  * </p>
  * @return string a unique function name as a string, or false on error.
  * @deprecated 7.2 Use anonymous functions instead.
+ * @removed 8.0
  */
 function create_function ($args, $code) {}
 
